@@ -1,7 +1,7 @@
 '''
-spotipy
+spotidry
 '''
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __author__ = 'Mike Boiko'
 __email__ = 'mike@boiko.ca'
